============
Installation
============

At the command line::

    $ easy_install webapp2_restful

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv webapp2_restful
    $ pip install webapp2_restful
